@@ -11,7 +11,7 @@ use warnings;
 use base qw( IO::Async::Notifier );
 IO::Async::Notifier->VERSION( '0.63' ); # adopt_future
 
-our $VERSION = '0.18_002';
+our $VERSION = '0.18_003';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -22,6 +22,8 @@ use JSON::MaybeXS qw( encode_json decode_json );
 
 use Data::Dump 'pp';
 use File::stat;
+use List::Util 1.29 qw( pairmap );
+use Scalar::Util qw( blessed );
 use Struct::Dumb;
 use Time::HiRes qw( time );
 use URI;
@@ -158,6 +160,12 @@ in receiveing any events, and wishes to reduce the load on the homeserver.
 Optional. Timeout in seconds for the C</events> longpoll operation. Defaults
 to 30 seconds if not supplied.
 
+=head2 first_sync_limit => NUM
+
+Optional. Number of events per room to fetch on the first C</sync> request on
+startup. Defaults to the server's builtin value if not defined, which is
+likely to be 10.
+
 =cut
 
 sub _init
@@ -210,6 +218,7 @@ sub configure
    my %params = @_;
 
    foreach (qw( server path_prefix ua SSL enable_events longpoll_timeout
+                first_sync_limit
                 on_log on_unknown_event on_presence on_room_new on_room_del on_invite
                 on_room_member on_room_message )) {
       $self->{$_} = delete $params{$_} if exists $params{$_};
@@ -231,6 +240,14 @@ sub log
    $self->{on_log}->( $message ) if $self->{on_log};
 }
 
+sub _maybe_encode
+{
+   my $v = shift;
+   return $v if !ref $v or blessed $v;
+   return $v if ref $v ne "HASH";
+   return encode_json( $v );
+}
+
 sub _uri_for_path
 {
    my $self = shift;
@@ -244,7 +261,9 @@ sub _uri_for_path
    $uri->path( $self->{path_prefix} . $path );
 
    $params{access_token} = $self->{access_token} if defined $self->{access_token};
-   $uri->query_form( %params );
+
+   # Some parameter values can be JSON-encoded objects
+   $uri->query_form( pairmap { $a => _maybe_encode $b } %params );
 
    return $uri;
 }
@@ -613,7 +632,12 @@ sub start
          $room->_reset_for_sync;
       }
 
-      $self->sync->then( sub {
+      my %first_sync_args;
+
+      $first_sync_args{filter}{room}{timeline}{limit} = $self->{first_sync_limit} 
+         if defined $self->{first_sync_limit};
+
+      $self->sync( %first_sync_args )->then( sub {
          my ( $sync ) = @_;
 
          $self->_incoming_sync( $sync );
@@ -659,7 +683,7 @@ sub start_longpoll
          $self->{make_delay}->( $self->{longpoll_timeout} + 5 )
             ->else_fail( "Longpoll timed out" ),
 
-         $self->_do_GET_json( "/sync",
+         $self->sync(
             since   => $last_token,
             timeout => $self->{longpoll_timeout} * 1000, # msec
          )->then( sub {
