@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2016 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2016-2017 -- leonerd@leonerd.org.uk
 
 package Net::Async::Matrix::Room::State;
 
@@ -14,7 +14,7 @@ use Struct::Dumb;
 
 struct Member => [qw( user displayname membership )];
 
-our $VERSION = '0.18_002';
+our $VERSION = '0.18_003';
 $VERSION = eval $VERSION;
 
 =head1 NAME
@@ -168,22 +168,41 @@ sub aliases
    @members = $state->members
 
 Returns a list of Member instances representing all of the members of the room
-from the C<m.room.member> events.
+from the C<m.room.member> events whose membership state is not C<leave>.
 
 =cut
 
 sub members
 {
    my $self = shift;
+   my ( $with_leaves ) = @_;
+
    return pairmap {
       my ( $user_id, $event ) = ( $a, $b );
+      my $content = $event->{content};
+
+      return () if $content->{membership} eq "leave" and !$with_leaves;
 
       my $user = $self->{matrix}->_get_or_make_user( $user_id );
-      my $content = $event->{content};
       Member( $user, $content->{displayname}, $content->{membership} );
    } %{ $self->get_events( "m.room.member" ) };
 }
 
+=head2 all_members
+
+   @members = $state->members
+
+Similar to L</members> but even includes members in C<leave> state. This is
+not normally what you want.
+
+=cut
+
+sub all_members
+{
+   my $self = shift;
+   return $self->members( 1 );
+}
+
 =head2 member
 
    $member = $state->member( $user_id )
