@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2014-2016 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2014-2017 -- leonerd@leonerd.org.uk
 
 package Net::Async::Matrix::Utils;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.18_002';
+our $VERSION = '0.18_003';
 $VERSION = eval $VERSION;
 
 use Exporter 'import';
@@ -176,7 +176,7 @@ sub build_formatted_message
 
    if( $str->tagnames and CAN_BUILD_HTML ) {
       my $html = String::Tagged::HTML->clone( $str,
-         only_tags => [qw( bold under italic strike fg )],
+         only_tags => [qw( bold italic under strike monospace fg )],
          convert_tags => {
             bold      => "strong",
             italic    => "em",
